import * as iam from "aws-cdk-lib/aws-iam";
import { Construct } from "constructs";
export { IAMAccessKey } from "./provider";
export interface ISSMSecureIAMAccessKeyProps {
    readonly parameterName: string;
    readonly region?: string;
    readonly user: iam.IUser;
}
/**
 * Custom resource that creates a new IAM access key for the given user, then stores the AccessKeyId and Secret in a SSM SecureString Parameter.
 *
 * @param props SSMSecureIAMAccessKeyProps
 *
 * @returns (Not actually returned) The Value of the Parameter is the JSON representation of the AccessKeyId and Secret:
 * @see IAMAccessKey
 * Example: { "accessKeyId": "AKIAXXXXXXXXXXXXXXXX", "secretAccessKey": "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX" }
 *
 * Give permission to use this secret SSM Parameter:
 * ssm.StringParameter.fromSecureStringParameterAttributes(this, "ID", {
 *     parameterName: this.props.parameterName,
 * });
 */
export declare class SSMSecureIAMAccessKey extends Construct {
    private readonly id;
    private readonly props;
    private readonly provider;
    constructor(scope: Construct, id: string, props: ISSMSecureIAMAccessKeyProps);
    private validateProps;
    private createAccessKeyCreatorProvider;
    private createResource;
}
